==> commons-0.3.4-sources.jar: com/flybits/commons/library/api/FlyAway.java <==
package com.flybits.commons.library.api;

import android.content.Context;
import android.support.annotation.NonNull;

import com.flybits.commons.library.deserializations.IDeserializer;
import com.flybits.commons.library.exceptions.FlybitsException;
import com.flybits.commons.library.http.HttpDefaultClass;
import com.flybits.commons.library.http.RequestStatus;
import com.flybits.commons.library.logging.Logger;
import com.flybits.commons.library.models.internal.PagedResponse;
import com.flybits.commons.library.models.internal.QueryParameters;
import com.flybits.commons.library.models.internal.Result;

import java.io.IOException;
import java.util.HashMap;

public class FlyAway {

    public static <T> Result<PagedResponse<T>> get(@NonNull Context mContext, @NonNull String urlEndpoint, QueryParameters params,
                                                   @NonNull IDeserializer deserializer, @NonNull String uniqueIdentifier) throws FlybitsException{

        return get(mContext, urlEndpoint, null, params, deserializer, uniqueIdentifier);
    }
    public static <T> Result<PagedResponse<T>> get(@NonNull Context mContext, @NonNull String urlEndpoint, HashMap<String, String> headers,
                                                    QueryParameters params, @NonNull IDeserializer deserializer, @NonNull String uniqueIdentifier) throws FlybitsException{

        if (mContext == null){
            throw new FlybitsException("The Context parameter must not be null");
        }
        if (urlEndpoint == null || urlEndpoint.length() == 0){
            throw new FlybitsException("The urlEndpoint parameter must be set");
        }
        if (deserializer == null){
            throw new FlybitsException("The IDeserializer parameter must not be null");
        }
        if (uniqueIdentifier == null){
            throw new FlybitsException("The uniqueIdentifier parameter must not be null");
        }

        String url = FlybitsAPIConstants.constructGatewayURL(urlEndpoint);

        try {

            Result<PagedResponse<T>> result = new HttpDefaultClass.Builder(mContext, true, url, params)
                    .addHeaders(headers)
                    .get()
                    .getResponse();

            if (result.getStatus() == RequestStatus.COMPLETED){
                PagedResponse<T> response = (PagedResponse<T>) deserializer.fromJson(result.getResultAsString());
                if (response != null){
                    result.setResponse(response);
                }else{
                    result = new Result<>(new FlybitsException("Parsing Error"), result.getResultAsString());
                }
            }

            return result;
        } catch (Exception e) {
            Logger.exception(uniqueIdentifier, e);
            if (e instanceof ClassCastException){
                throw new FlybitsException("Invalid Deserializer for this request: "+ deserializer.getClass());
            }else {
                throw new FlybitsException("Error Connecting to Flybits Server: " + uniqueIdentifier);
            }
        }
    }

    public static <T> Result<T> get(@NonNull Context mContext, @NonNull String urlEndpoint,
                                    @NonNull IDeserializer deserializer, @NonNull String uniqueIdentifier,
                                    @NonNull Class<T> type) throws FlybitsException{

        return get(mContext, urlEndpoint, null, deserializer, uniqueIdentifier, type);
    }

    public static <T> Result<T> get(@NonNull Context mContext, @NonNull String urlEndpoint, HashMap<String, String> headers,
                                    @NonNull IDeserializer deserializer, @NonNull String uniqueIdentifier,
                                    @NonNull Class<T> type) throws FlybitsException{

        if (mContext == null){
            throw new FlybitsException("The Context parameter must not be null");
        }
        if (urlEndpoint == null || urlEndpoint.length() == 0){
            throw new FlybitsException("The urlEndpoint parameter must be set");
        }
        if (type == null){
            throw new FlybitsException("The Class parameter must not be null");
        }
        if (deserializer == null){
            throw new FlybitsException("The IDeserializer parameter must not be null");
        }
        if (uniqueIdentifier == null){
            throw new FlybitsException("The uniqueIdentifier parameter must not be null");
        }

        String url = FlybitsAPIConstants.constructGatewayURL(urlEndpoint);

        try {

            Result<T> result = new HttpDefaultClass.Builder(mContext, true, url)
                    .addHeaders(headers)
                    .get()
                    .getResponse();
            if (result.getStatus() == RequestStatus.COMPLETED){
                T response = type.cast(deserializer.fromJson(result.getResultAsString()));
                if (response != null){
                    result.setResponse(response);
                }else{
                    result = new Result<>(new FlybitsException("Parsing Error"), result.getResultAsString());
                }
            }

            return result;
        } catch (Exception e) {
            if (e instanceof ClassCastException){
                throw new FlybitsException("Invalid Deserializer for this request: "+ deserializer.getClass());
            }else {
                throw new FlybitsException("Error Connecting to Flybits Server: " + uniqueIdentifier);
            }
        }
    }

    public static <T> Result<T> post(@NonNull Context mContext, @NonNull String urlEndpoint, String requestBody,
                                     IDeserializer deserializer, @NonNull String uniqueIdentifier, Class<T> type) throws FlybitsException{
        return post(mContext, urlEndpoint, null, requestBody, deserializer, uniqueIdentifier, type);
    }

    public static <T> Result<T> post(@NonNull Context mContext, @NonNull String urlEndpoint, HashMap<String, String> headers, String requestBody,
                                     IDeserializer deserializer, @NonNull String uniqueIdentifier, Class<T> type) throws FlybitsException{
        if (mContext == null){
            throw new FlybitsException("The Context parameter must not be null");
        }
        if (urlEndpoint == null || urlEndpoint.length() == 0){
            throw new FlybitsException("The urlEndpoint parameter must be set");
        }
        if (uniqueIdentifier == null){
            throw new FlybitsException("The uniqueIdentifier parameter must not be null");
        }
        if (requestBody == null){
            requestBody = "";
        }

        String url = FlybitsAPIConstants.constructGatewayURL(urlEndpoint);

        try {

            Result<T> result = new HttpDefaultClass.Builder(mContext, true, url)
                    .addHeaders(headers)
                    .post(requestBody)
                    .getResponse();
            if (result.getStatus() == RequestStatus.COMPLETED){
                if (type != null) {
                    T response = type.cast(deserializer.fromJson(result.getResultAsString()));
                    if (response != null) {
                        result.setResponse(response);
                    } else {
                        result = new Result<>(new FlybitsException("Parsing Error"), result.getResultAsString());
                    }
                }
            }

            return result;
        } catch (Exception e) {
            if (e instanceof ClassCastException){
                throw new FlybitsException("Invalid Deserializer for this request: "+ deserializer.getClass());
            }else {
                throw new FlybitsException("Error Connecting to Flybits Server: " + uniqueIdentifier);
            }
        }
    }

    public static <T> Result<T> put(@NonNull Context mContext, @NonNull String urlEndpoint, @NonNull String requestBody,
                                    IDeserializer deserializer, @NonNull String uniqueIdentifier, Class<T> type) throws FlybitsException{
       return put(mContext, urlEndpoint, null, requestBody, deserializer, uniqueIdentifier, type);
    }

    public static <T> Result<T> put(@NonNull Context mContext, @NonNull String urlEndpoint, HashMap<String, String> headers, @NonNull String requestBody,
                                    IDeserializer deserializer, @NonNull String uniqueIdentifier, Class<T> type) throws FlybitsException{
        if (mContext == null){
            throw new FlybitsException("The Context parameter must not be null");
        }
        if (urlEndpoint == null || urlEndpoint.length() == 0){
            throw new FlybitsException("The urlEndpoint parameter must be set");
        }
        if (uniqueIdentifier == null){
            throw new FlybitsException("The uniqueIdentifier parameter must not be null");
        }
        if (requestBody == null){
            throw new FlybitsException("The Request body parameter must not be null");
        }

        String url = FlybitsAPIConstants.constructGatewayURL(urlEndpoint);

        try {
            Result<T> result = new HttpDefaultClass.Builder(mContext, true, url)
                    .addHeaders(headers)
                    .put(requestBody)
                    .getResponse();
            if (result.getStatus() == RequestStatus.COMPLETED){
                if (type != null) {
                    T response = type.cast(deserializer.fromJson(result.getResultAsString()));
                    if (response != null) {
                        result.setResponse(response);
                    } else {
                        result = new Result<>(new FlybitsException("Parsing Error"), result.getResultAsString());
                    }
                }
            }

            return result;
        } catch (Exception e) {
            if (e instanceof ClassCastException){
                throw new FlybitsException("Invalid Deserializer for this request: "+ deserializer.getClass());
            }else {
                throw new FlybitsException("Error Connecting to Flybits Server: " + uniqueIdentifier);
            }
        }
    }

    public static Result delete(@NonNull Context mContext, @NonNull String urlEndpoint,
                                @NonNull String uniqueIdentifier, String id) throws FlybitsException{
        return delete(mContext, urlEndpoint, null, uniqueIdentifier, id);
    }


    public static Result delete(@NonNull Context mContext, @NonNull String urlEndpoint, HashMap<String, String> headers,
                                @NonNull String uniqueIdentifier, String id) throws FlybitsException {

        if (mContext == null) {
            throw new FlybitsException("The Context parameter must not be null");
        }
        if (urlEndpoint == null || urlEndpoint.length() == 0) {
            throw new FlybitsException("The urlEndpoint parameter must be set");
        }
        if (uniqueIdentifier == null) {
            throw new FlybitsException("The uniqueIdentifier parameter must not be null");
        }

        String url = FlybitsAPIConstants.constructGatewayURL(urlEndpoint);
        if (id != null) {
            url += ("/" + id);
        }

        try {
            return new HttpDefaultClass.Builder(mContext, true, url)
                    .addHeaders(headers)
                    .delete()
                    .getResponse();
        } catch (IOException | NullPointerException e) {
            Logger.exception(uniqueIdentifier, e);
            throw new FlybitsException("Error Connecting to Flybits Server: " + uniqueIdentifier);
        }
    }
}

==> commons-0.5.0-sources.jar: com/flybits/commons/library/api/FlyAway.java <==
package com.flybits.commons.library.api;

import android.content.Context;
import android.support.annotation.NonNull;

import com.flybits.commons.library.deserializations.IDeserializer;
import com.flybits.commons.library.exceptions.FlybitsException;
import com.flybits.commons.library.http.HttpDefaultClass;
import com.flybits.commons.library.http.RequestStatus;
import com.flybits.commons.library.logging.Logger;
import com.flybits.commons.library.models.internal.PagedResponse;
import com.flybits.commons.library.models.internal.QueryParameters;
import com.flybits.commons.library.models.internal.Result;

import java.io.IOException;
import java.util.HashMap;

public class FlyAway {

    public static <T> Result<PagedResponse<T>> get(@NonNull Context mContext, @NonNull String urlEndpoint, QueryParameters params,
                                                   @NonNull IDeserializer deserializer, @NonNull String uniqueIdentifier) throws FlybitsException{

        return get(mContext, urlEndpoint, null, params, deserializer, uniqueIdentifier);
    }
    public static <T> Result<PagedResponse<T>> get(@NonNull Context context, @NonNull String urlEndpoint, HashMap<String, String> headers,
                                                    QueryParameters params, @NonNull IDeserializer deserializer, @NonNull String uniqueIdentifier) throws FlybitsException{

        if (context == null){
            throw new FlybitsException("The Context parameter must not be null");
        }
        if (urlEndpoint == null || urlEndpoint.length() == 0){
            throw new FlybitsException("The urlEndpoint parameter must be set");
        }
        if (deserializer == null){
            throw new FlybitsException("The IDeserializer parameter must not be null");
        }
        if (uniqueIdentifier == null){
            throw new FlybitsException("The uniqueIdentifier parameter must not be null");
        }

        String url = FlybitsAPIConstants.constructGatewayURL(context, urlEndpoint);

        try {

            Result<PagedResponse<T>> result = new HttpDefaultClass.Builder(context, true, url, params)
                    .addHeaders(headers)
                    .get()
                    .getResponse();

            if (result.getStatus() == RequestStatus.COMPLETED){
                PagedResponse<T> response = (PagedResponse<T>) deserializer.fromJson(result.getResultAsString());
                if (response != null){
                    result.setResponse(response);
                }else{
                    result = new Result<>(new FlybitsException("Parsing Error"), result.getResultAsString());
                }
            }

            return result;
        } catch (Exception e) {
            Logger.exception(uniqueIdentifier, e);
            if (e instanceof ClassCastException){
                throw new FlybitsException("Invalid Deserializer for this request: "+ deserializer.getClass());
            }else {
                throw new FlybitsException("Error Connecting to Flybits Server: " + uniqueIdentifier);
            }
        }
    }

    public static <T> Result<T> get(@NonNull Context context, @NonNull String urlEndpoint,
                                    @NonNull IDeserializer deserializer, @NonNull String uniqueIdentifier,
                                    @NonNull Class<T> type) throws FlybitsException{

        return get(context, urlEndpoint, null, deserializer, uniqueIdentifier, type);
    }

    public static <T> Result<T> get(@NonNull Context context, @NonNull String urlEndpoint, HashMap<String, String> headers,
                                    @NonNull IDeserializer deserializer, @NonNull String uniqueIdentifier,
                                    @NonNull Class<T> type) throws FlybitsException{

        if (context == null){
            throw new FlybitsException("The Context parameter must not be null");
        }
        if (urlEndpoint == null || urlEndpoint.length() == 0){
            throw new FlybitsException("The urlEndpoint parameter must be set");
        }
        if (type == null){
            throw new FlybitsException("The Class parameter must not be null");
        }
        if (deserializer == null){
            throw new FlybitsException("The IDeserializer parameter must not be null");
        }
        if (uniqueIdentifier == null){
            throw new FlybitsException("The uniqueIdentifier parameter must not be null");
        }

        String url = FlybitsAPIConstants.constructGatewayURL(context, urlEndpoint);

        try {

            Result<T> result = new HttpDefaultClass.Builder(context, true, url)
                    .addHeaders(headers)
                    .get()
                    .getResponse();
            if (result.getStatus() == RequestStatus.COMPLETED){
                T response = type.cast(deserializer.fromJson(result.getResultAsString()));
                if (response != null){
                    result.setResponse(response);
                }else{
                    result = new Result<>(new FlybitsException("Parsing Error"), result.getResultAsString());
                }
            }

            return result;
        } catch (Exception e) {
            if (e instanceof ClassCastException){
                throw new FlybitsException("Invalid Deserializer for this request: "+ deserializer.getClass());
            }else {
                throw new FlybitsException("Error Connecting to Flybits Server: " + uniqueIdentifier);
            }
        }
    }

    public static <T> Result<T> post(@NonNull Context context, @NonNull String urlEndpoint, String requestBody,
                                     IDeserializer deserializer, @NonNull String uniqueIdentifier, Class<T> type) throws FlybitsException{
        return post(context, urlEndpoint, null, requestBody, deserializer, uniqueIdentifier, type);
    }

    public static <T> Result<T> post(@NonNull Context context, @NonNull String urlEndpoint, HashMap<String, String> headers, String requestBody,
                                     IDeserializer deserializer, @NonNull String uniqueIdentifier, Class<T> type) throws FlybitsException{
        if (context == null){
            throw new FlybitsException("The Context parameter must not be null");
        }
        if (urlEndpoint == null || urlEndpoint.length() == 0){
            throw new FlybitsException("The urlEndpoint parameter must be set");
        }
        if (uniqueIdentifier == null){
            throw new FlybitsException("The uniqueIdentifier parameter must not be null");
        }
        if (requestBody == null){
            requestBody = "";
        }

        String url = FlybitsAPIConstants.constructGatewayURL(context, urlEndpoint);

        try {

            Result<T> result = new HttpDefaultClass.Builder(context, true, url)
                    .addHeaders(headers)
                    .post(requestBody)
                    .getResponse();
            if (result.getStatus() == RequestStatus.COMPLETED){
                if (type != null) {
                    T response = type.cast(deserializer.fromJson(result.getResultAsString()));
                    if (response != null) {
                        result.setResponse(response);
                    } else {
                        result = new Result<>(new FlybitsException("Parsing Error"), result.getResultAsString());
                    }
                }
            }

            return result;
        } catch (Exception e) {
            if (e instanceof ClassCastException){
                throw new FlybitsException("Invalid Deserializer for this request: "+ deserializer.getClass());
            }else {
                throw new FlybitsException("Error Connecting to Flybits Server: " + uniqueIdentifier);
            }
        }
    }

    public static <T> Result<T> put(@NonNull Context context, @NonNull String urlEndpoint, @NonNull String requestBody,
                                    IDeserializer deserializer, @NonNull String uniqueIdentifier, Class<T> type) throws FlybitsException{
       return put(context, urlEndpoint, null, requestBody, deserializer, uniqueIdentifier, type);
    }

    public static <T> Result<T> put(@NonNull Context context, @NonNull String urlEndpoint, HashMap<String, String> headers, @NonNull String requestBody,
                                    IDeserializer deserializer, @NonNull String uniqueIdentifier, Class<T> type) throws FlybitsException{
        if (context == null){
            throw new FlybitsException("The Context parameter must not be null");
        }
        if (urlEndpoint == null || urlEndpoint.length() == 0){
            throw new FlybitsException("The urlEndpoint parameter must be set");
        }
        if (uniqueIdentifier == null){
            throw new FlybitsException("The uniqueIdentifier parameter must not be null");
        }
        if (requestBody == null){
            throw new FlybitsException("The Request body parameter must not be null");
        }

        String url = FlybitsAPIConstants.constructGatewayURL(context, urlEndpoint);

        try {
            Result<T> result = new HttpDefaultClass.Builder(context, true, url)
                    .addHeaders(headers)
                    .put(requestBody)
                    .getResponse();
            if (result.getStatus() == RequestStatus.COMPLETED){
                if (type != null) {
                    T response = type.cast(deserializer.fromJson(result.getResultAsString()));
                    if (response != null) {
                        result.setResponse(response);
                    } else {
                        result = new Result<>(new FlybitsException("Parsing Error"), result.getResultAsString());
                    }
                }
            }

            return result;
        } catch (Exception e) {
            if (e instanceof ClassCastException){
                throw new FlybitsException("Invalid Deserializer for this request: "+ deserializer.getClass());
            }else {
                throw new FlybitsException("Error Connecting to Flybits Server: " + uniqueIdentifier);
            }
        }
    }

    public static Result delete(@NonNull Context context, @NonNull String urlEndpoint,
                                @NonNull String uniqueIdentifier, String id) throws FlybitsException{
        return delete(context, urlEndpoint, null, uniqueIdentifier, id);
    }


    public static Result delete(@NonNull Context context, @NonNull String urlEndpoint, HashMap<String, String> headers,
                                @NonNull String uniqueIdentifier, String id) throws FlybitsException {

        if (context == null) {
            throw new FlybitsException("The Context parameter must not be null");
        }
        if (urlEndpoint == null || urlEndpoint.length() == 0) {
            throw new FlybitsException("The urlEndpoint parameter must be set");
        }
        if (uniqueIdentifier == null) {
            throw new FlybitsException("The uniqueIdentifier parameter must not be null");
        }

        String url = FlybitsAPIConstants.constructGatewayURL(context, urlEndpoint);
        if (id != null) {
            url += ("/" + id);
        }

        try {
            return new HttpDefaultClass.Builder(context, true, url)
                    .addHeaders(headers)
                    .delete()
                    .getResponse();
        } catch (IOException | NullPointerException e) {
            Logger.exception(uniqueIdentifier, e);
            throw new FlybitsException("Error Connecting to Flybits Server: " + uniqueIdentifier);
        }
    }
}
